@@ -57,4 +57,8 @@ class IThesaurusTermsListFieldWidget(ISequenceWidget):
                                   required=True,
                                   default=False)
 
+    backspace_removes_last = Bool(title=_("Backspace key removes last value?"),
+                                  required=True,
+                                  default=True)
+
     terms = Attribute(_("Widget terms"))
