@@ -22,7 +22,7 @@
 
 # import Zope3 packages
 from zope.interface import Interface
-from zope.schema import TextLine
+from zope.schema import TextLine, Bool
 
 # import local packages
 
@@ -32,12 +32,22 @@ from ztfy.thesaurus import _
 class IThesaurusTermFieldIndex(Interface):
     """Thesaurus term field index interface"""
 
-    thesaurus_name = TextLine(title=_("Thesaurus name"),
-                              required=False)
+    include_parents = Bool(title=_("Include term parents into index values"),
+                           default=False,
+                           required=False)
+
+    include_synonyms = Bool(title=_("Include term synonyms into index values"),
+                            default=False,
+                            required=False)
 
 
 class IThesaurusTermsListFieldIndex(Interface):
     """Thesaurus terms list field index interface"""
 
-    thesaurus_name = TextLine(title=_("Thesaurus name"),
-                              required=False)
+    include_parents = Bool(title=_("Include term parents into index values"),
+                           default=False,
+                           required=False)
+
+    include_synonyms = Bool(title=_("Include term synonyms into index values"),
+                            default=False,
+                            required=False)
